package com.fastest.pass.home.presentation.ui.component

import androidx.compose.foundation.layout.padding
import androidx.compose.material.BottomNavigation
import androidx.compose.material.BottomNavigationItem
import androidx.compose.material.Icon
import androidx.compose.material.Scaffold
import androidx.compose.material.Text
import androidx.compose.runtime.Composable
import androidx.compose.ui.Modifier
import androidx.compose.ui.res.painterResource
import androidx.navigation.NavController
import androidx.navigation.compose.NavHost
import androidx.navigation.compose.composable
import androidx.navigation.compose.currentBackStackEntryAsState
import androidx.navigation.compose.rememberNavController
import com.fastest.pass.home.domain.model.Screen
import com.fastest.pass.welcome.presentation.ui.fragment.WelcomeFragment

enum class HomeClickType {
    HOME,
    BROWSE,
    SECURITY,
    ACCOUNT
}

@Composable
fun HomeScreen() {

}

@Composable
fun BottomTabNavigation(onClick: (homeClick: HomeClickType) -> Unit) {
    val navController = rememberNavController()

    Scaffold(
        bottomBar = {
            BottomNavigationBar(navController = navController)
        }
    ) { paddingValues ->
        // Host Fragments instead of Composables
        NavHost(
            navController = navController,
            startDestination = Screen.Home.route,
            modifier = Modifier.padding(paddingValues) // Using paddingValues from Scaffold
        ) {
            composable(Screen.Home.route) {
                // Fragment or content for Home
                WelcomeFragment()
            }
            composable(Screen.Browse.route) {
                // Fragment or content for Browse
            }
            composable(Screen.Security.route) {
                // Fragment or content for Security
            }
            composable(Screen.Account.route) {
                // Fragment or content for Account
            }
        }
    }

}
@Composable
fun BottomNavigationBar(navController: NavController) {
    val items = listOf(Screen.Home, Screen.Browse, Screen.Security, Screen.Account)
    val currentBackStackEntry = navController.currentBackStackEntryAsState()
    val currentRoute = currentBackStackEntry.value?.destination?.route

    BottomNavigation {
        items.forEach { screen ->
            BottomNavigationItem(
                icon = { Icon(painterResource(id = screen.icon), contentDescription = null) },
                label = { Text(screen.title) },
                selected = currentRoute == screen.route,
                onClick = {
                    navController.navigate(screen.route) {
                        // Avoid multiple copies of the same destination
                        popUpTo(navController.graph.startDestinationId) {
                            saveState = true
                        }
                        launchSingleTop = true
                        restoreState = true
                    }
                }
            )
        }
    }
}